@@ -230,7 +230,7 @@ class DataPlate:
         import pandas as pd
         with tempfile.NamedTemporaryFile(suffix='.gz') as t:
             output_file = t.name
-            self.query(query, output_file, refresh, async_m, request_timeout)
+            self.query(query, output_file, refresh, async_m, request_timeout, es_index_type, bucket_suffixes, bucket_filter)
             with open(output_file, 'rb') as fh:
                 return pd.read_json(fh, compression='gzip', lines=True, **kwargs)
 
